@@ -11,9 +11,10 @@ namespace unievent {
 
 template <class TYPE> struct Typemap<panda::unievent::Handle*, TYPE> : TypemapObject<panda::unievent::Handle*, TYPE, ObjectTypeRefcntPtr, ObjectStorageMGBackref, DynamicCast> {
     using Super = TypemapObject<panda::unievent::Handle*, TYPE, ObjectTypeRefcntPtr, ObjectStorageMGBackref, DynamicCast>;
+    static panda::string_view package() {return "";}
     static Sv create (const TYPE& var, Sv proto = Sv()) {
         if (!var) return &PL_sv_undef;
-        if (!proto) {
+        if (!proto && !Typemap<TYPE>::package().length()) {
             proto = unievent::handle_perl_class(var->type());
         }
         return Super::create(var, proto);
